FL.objects.Component.Component
==============================

.. currentmodule:: FL.objects.Component

.. autoclass:: Component
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Component.Get
      ~Component.Paste
      ~Component.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Component.delta
      ~Component.deltas
      ~Component.index
      ~Component.parent
      ~Component.scale
      ~Component.scales
   
   